@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
-our $DATE = '2015-11-07'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2016-02-14'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -195,6 +195,8 @@ sub munge_module {
                 my $res = call_lcpan_script(
                     argv => ["mod2dist", keys %{$self->{_mods}}],
                 );
+                $self->log_fatal(["Can't lcpan mod2dist: %s - %res", $res->[0], $res->[1]])
+                    unless $res->[0] == 200;
                 for (values %$res) {
                     $self->{_dists}{$_} = 0;
                 }
@@ -248,7 +250,7 @@ Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using '
 
 =head1 VERSION
 
-This document describes version 0.17 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-11-07.
+This document describes version 0.18 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2016-02-14.
 
 =head1 SYNOPSIS
 
@@ -310,10 +312,6 @@ scripts in the distribution.
 
 Exclude a script. Can be specified multiple times.
 
-=head1 SEE ALSO
-
-L<depak>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-Depak>.
@@ -330,13 +328,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<depak>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
